@@ -28,4 +28,10 @@ test_that('Test Plotting Processed Data With Topography', {
   plot(sinkhole@profiles[[1]],
        dataType = 'processed',
        withTopo = T)
+})
+
+test_that('Test Plotting Profile Set With Topography', {
+  plot(sinkhole,
+       dataType = 'processed',
+       withTopo = T)
 })
\ No newline at end of file
